/// <reference types="node" />
import { DumpOptions, LoadOptions, YAMLException } from 'js-yaml';
export declare namespace Function {
    type Loader = (data: string, options?: LoadOptions) => any;
    type Dumper = (data: any, options?: DumpOptions) => string;
    type AsyncReader = (source: FileSystem.Path, options?: Options.LoadRead) => Promise<any>;
    type AsyncWriter = (data: any, target: FileSystem.Path, options?: Options.DumpWrite) => Promise<void>;
    type SyncReader = (source: FileSystem.Path, options?: Options.LoadRead) => any;
    type SyncWriter = (data: any, target: FileSystem.Path, options?: Options.DumpWrite) => void;
}
export declare namespace FileSystem {
    interface ReadObjectOptions {
        readonly encoding: Encoding;
        readonly flag?: Flag;
    }
    interface WriteObjectOptions {
        readonly encoding?: Encoding | null;
        readonly flag?: Flag;
        readonly mode?: number;
    }
    type Encoding = BufferEncoding;
    type Flag = 'a' | 'ax' | 'a+' | 'ax+' | 'as' | 'r' | 'r+' | 'rs+';
    type ReadOptions = Encoding | ReadObjectOptions;
    type WriteOptions = WriteObjectOptions;
    type Path = string | Buffer;
    type WritableData = Buffer | string;
}
export declare namespace Options {
    type LoadYaml = LoadOptions;
    type DumpYaml = DumpOptions;
    type ReadFile = FileSystem.ReadOptions;
    type WriteFile = FileSystem.WriteOptions;
    type LoadRead = LoadYaml & FileSystem.ReadObjectOptions;
    type DumpWrite = DumpYaml & FileSystem.WriteObjectOptions;
}
export declare class LoadFileError extends Error {
    readonly filename: FileSystem.Path;
    readonly yamlException: YAMLException;
    constructor(filename: FileSystem.Path, yamlException: YAMLException);
}
